Enum dynamo_subscriber::error::Error
source · pub enum Error {
NotFoundStream(String),
NotFoundStreamDescription(String),
SdkError(Box<dyn Error + Send + Sync + 'static>),
}Expand description
All possible error types for this crate.
Variants
NotFoundStream(String)
Not found stream arn when attempting to get table description for given table name.
NotFoundStreamDescription(String)
Not found stream description when attempting to get stream description.
SdkError(Box<dyn Error + Send + Sync + 'static>)
Any other errors from the aws sdk.