pub struct GetShardsOutput {
    pub shards: Vec<Shard>,
    pub last_shard_id: Option<String>,
}
An output representation of get shards operation.

Fields

shards: Vec<Shard>

The shards that are retrieved by the operation.

last_shard_id: Option<String>

The shard ID of the item where the operation stopped, inclusive of the previous result set. Use this value to start a new operation, excluding this value in the new request.

If last_shard_id is None, then the “last page” of results has been processed and there is currently no more data to be retrieved.

If last_shard_id is Some, it does not necessarily mean that there is more data in the result set. The only way to know when you have reached the end of the result set is when last_shard_id is None.