Struct dynamo_subscriber::types::Lineage
source · pub struct Lineage { /* private fields */ }Expand description
A representation of shard lineage(parent and children).
Because an application must always process a parent shard before it processes a child shard, this struct ensures that the stream records are processed in the correct order.