Struct dynamo_subscriber::types::Lineages
source · pub struct Lineages(/* private fields */);Expand description
A representation of group of shard lineage(parent and children).
Implementations
sourceimpl Lineages
impl Lineages
sourcepub async fn get_records<Client>(
self,
client: Arc<Client>
) -> (Vec<Shard>, Vec<Record>)where
Client: DynamodbClient + 'static,
pub async fn get_records<Client>( self, client: Arc<Client> ) -> (Vec<Shard>, Vec<Record>)where Client: DynamodbClient + 'static,
Get records in the correct order and shards with renewed shard iterator ids.
Each lineage is processed in the correct order (parent shard is processed before the children), and lineages without any releationships are processed concurrently.
Returned records are sorted by its sequence number.